%
% About:
%   This script is part of the supplementary material for the manuscript
%   entitled "Efficient bulk mass accommodation and dissociation
%   of N2O5 in neutral aqueous aerosol", submitted to Atmospheric Chemistry and Physics,
%   (Grinic et al., 2017).
%
%
% Aqueous phase chemistry of N2O5 with differentiated 13N label and
% exchange with gas phase

% NNO5 --> NO2+ + NO3-        k(1)
% N*NO5 --> N*O2+ + NO3-      k(1)/2  total decay of N*NO5 must remain k(1)
% N*NO5 --> NO2+ + N*O3-      k(1)/2  at each decay 50% chance for each
% NO2+ + NO3- --> NNO5        k(2)
% N*O2+ + NO3- --> N*NO5      k(2)
% NO2+ + N*O3- --> N*NO5      k(2)
% NO2+ + H2O --> NO3- + 2H+   k(3)
% N*O2+ + H2O --> N*O3- + 2H+ k(3)
% NNO5g --> NNO5  (g-->aq)    k(4)(aq), k(5)(g)
% N*NO5g --> NNO5  (g-->aq)   k(4)(aq), k(5)(g)
% NNO5 --> NNO5g  (aq-->g)    k(6)(aq), k(7)(g)
% N*NO5 --> N*NO5g  (aq-->g)  k(6)(aq), k(7)(g)
% 

% c(1)=NNO5,c(2)=N*NO5,c(3)=NO2+,c(4)=N*O2+,c(5)=NO3-,c(6)=N*O3-,
% c(7)=H2O,c(8)=H+,c(9)=NNO5g, c(10)=N*NO5g 

clear all;

global k

% Variables
%-------------------------------------------------------------------------
%-------------------------------------------------------------------------

T=273.15+(22); % temperature in K
p_room= 975*1E-3; % bar (1 atm = 1.01325 bar)

R=8.314472; % gas constant in j/(K mol)
N_A=6.02205E23; % avogadro's number in molecules/mol
N_M=2.46E19*(p_room/1.01325);   % Air in molecules cm-3
ppb=p_room/(R*T)*N_A*1E5*1E-6*1E-9; % 1 ppb in molecules cm-3
Henry=5; % Henry constant in M/atm as used by Mentel
Henryd=Henry/N_M; % Henry constant in M/(molecule cm-3)
N2O5g0=5e-9; % initial gas phase partial pressure of N2O5 in atm
N13NO5g0=N2O5g0/1e6; %initial gas phase partial pressure of 13N-labelled N2O5 in atm
H2O0=38.2; % initial water molarity aqueous phase, AIM: 70%RH;NaNO3:38.2 M
NO30=8.8; % initial nitrate molarity aqueous phase, AIM: at 70%RH NaNO3:8.8 M
N13O30=0; % initial labelled nitrate molarity aqueous phase
Hplus0=1e-7; % initial proton molarity aqueous phase
diamp=400e-7; % particle diameter in cm
volp=4/3*(diamp/2)^3*pi/1000; %particle volume in L
surfp=4*pi*(diamp/2)^2; %particle surface area in cm^2
Numberp=1e4; %particle number in particle / cm^3
VolAer=Numberp*volp; %liquid phase aerosol volume in L/cm^3
MassAer=VolAer*1*1000*1e6*1e6; % mass concentration in g / m^3
SurfAer=Numberp*surfp; % surface of aerosol in cm^2 / cm^3
alpha=1; % bulk accommodation coefficient
omega_N2O5=sqrt((8*R*T)/(pi*0.108))*1E2; % mean thermal velocity N2O5 (cm s-1)
% betaBT=1.15e6; % /s, 1.15e6  from Bertram and Thornton 2009
% deltaBT=1.3e-1; % /M from Bertram and Thornton 2009
kII3=1e9/H2O0; % /M /s, 1e9/H2O0 (H2O0 in mol/kg) from Mentel et al. 1999, referred back to Behnke et al 1997 and Taylor 1990
kdiss=5e6; % /s, 5e6 from Mentel
krec=2.4e9;... % /M /s, 2.4e10 (Mentel, nitrate)
% Rate coefficients
k=[kdiss;...
   krec;...
   kII3;...
   alpha*omega_N2O5/4*surfp/volp/N_A;...
   alpha*omega_N2O5/4*SurfAer;...
   alpha*omega_N2O5/4*surfp/volp/Henryd/N_A;...
   alpha*omega_N2O5/4*SurfAer/Henryd]; % rate constants ; k(3)/k(2) about 0.06

% Concentration species
% c(1)=NNO5,c(2)=N*NO5,c(3)=NO2+,c(4)=N*O2+,c(5)=NO3-,c(6)=N*O3-,
% c(7)=H2O,c(8)=H+,c(9)=NNO5g, c(10)=N*NO5g

c0=[0;0;0;0;NO30;N13O30;...
    H2O0;Hplus0;N2O5g0*N_M;N13NO5g0*N_M]; % initial concentrations

% N2O5 fate in aqueous phase
%-------------------------------------------------------------------------
%-------------------------------------------------------------------------

% n=9999;
% y = logspace(-3,4,n);
n=9999;
y = logspace(-5,1,n);

% options = odeset('RelTol',1e-9,'AbsTol',1e-8,'Stats','on');
% [t,C]=ode23s('ode_N2O5_13N_aq_01',y,c0,options); % call ode-solver
% [t,C]=ode45('ode_N2O5_13N_aq_01',y,c0); % call ode-solver
[t,C]=ode23tb('ode_N2O5_13N_aq_01',y,c0); % call ode-solver

RNNO5=-k(1)*C(:,1)+k(2)*C(:,3).*C(:,5); % d/dt [NNO5] net loss rate of N2O5 within aqueous phase
kIINNO5=-RNNO5./C(:,7)./C(:,1); % effective second order loss rate coefficient aqueous phase

RNNO5g=-k(5)*C(:,9)+k(7)*C(:,1); % net loss rate of N2O5 in the gas phase
RN13NO5g=-k(5)*C(:,10)+k(7)*C(:,2); % net loss rate of labelled N2O5 in the gas phase
gammaNNO5=-RNNO5g./C(:,9)/(omega_N2O5/4*SurfAer); % effective gamma N2O5
gammaN13NO5=-RN13NO5g./C(:,10)/(omega_N2O5/4*SurfAer); % effective gamma labelled N2O5
%normalized gas phase concentrations
CnormNNO5=C(:,9)/C(1,9);
CnormN13NO5=C(:,10)/C(1,10);
CnormN13O3=C(:,6)*VolAer*N_A/C(1,10)/1;%labelled nitrate taken up normalized to initial gas phase concentration (not divide by 2! only one label per N2O5)
CnormNO3=(C(:,5)-NO30)*VolAer*N_A/C(1,9)/2;%non-labelled nitrate taken up normalized to initial gas phase concentration (divide by 2 since N2O5
% can produce two non-labelled nitrates

% comparison of rates
RN13O2pNO3m=k(2)*C(:,4).*C(:,5); % loss rate of N*O2+ due to N*O2+ + NO3- --> N*NO5      k(2)
RN13O2pH2O=k(3)*C(:,4).*C(:,7); % loss rate of N*O2+ due to N*O2+ + H2O --> N*O3- + 2H+ k(3)
RN13O3mNO2p=k(2)*C(:,6).*C(:,3); % loss rate of N*O3- due to NO2+ + N*O3- --> N*NO5      k(2)
RNO2pNO3m=k(2)*C(:,3).*C(:,5); % loss rate of NO2+ due to NO2+ + NO3- --> NNO5      k(2)
RNO2pH2O=k(3)*C(:,3).*C(:,7); % loss rate of NO2+ due to NO2+ + H2O --> NO3- + 2H+ k(3)
RNO3mNO2p=k(2)*C(:,5).*C(:,3); % loss rate of NO3- due to NO2+ + NO3- --> NNO5      k(2)
RNNO5diss=k(1)*C(:,1);
RN13NO5diss=k(1)*C(:,2);

%fraction of labelled aqueous phase N2O5
fracN13NO5=C(:,2)./C(:,1)/1e-6;

%Ratio of labelled nitrate to total amount of label available
ratioN13O3=C(:,6)/(N13NO5g0*N_M/VolAer/N_A);

%effective Henry
Henryeff=(C(:,1)+C(:,3)+C(:,5)-NO30)/N2O5g0;

% Figure plotting
scrsz = get(groot,'ScreenSize');
figure('Position',[1 scrsz(4)/2 scrsz(3)/2 scrsz(4)/2])
loglog(t,C(:,1:8)) % plotting C(:,1) to C(:,8) vs t
xlabel('Time (s)');ylabel('Conc. (M) or molec /cc'); % plot axis label
legend('N2O5','N13NO5','NO2+','N13O2+','NO3-','N13O3-','H2O','H+','Location','NorthEastOutside'); % legend

% plot normalized gas phase concentrations
figure('Position',[scrsz(3)/2 scrsz(4)/2 scrsz(3)/2 scrsz(4)/2])
plot(t,CnormNNO5,t,CnormN13NO5,t,CnormNO3,t,CnormN13O3)
xlabel('Time (s)');ylabel('normalized concentration per volume of gas phase');
legend('C(N2O5)','C(N13NO5)','C(NO3-)','C(N13O3-)','Location','NorthEastOutside'); % legend

%plot fraction of label in aqueous phase NNO5 pool
figure('Position',[scrsz(3)/2 scrsz(4)/2 scrsz(3)/2 scrsz(4)/2])
plot(t,fracN13NO5,t,ratioN13O3)
axis([0 10 0 1]);
xlabel('Time (s)');ylabel('fraction of label in aqueous phase NNO5 pool / in nitrate taken up');
legend('fracN13NO5','ratioN13O3','Location','NorthEastOutside');


%plot gamma
figure('Position',[1 1 scrsz(3)/2 scrsz(4)/2])
semilogy(t,gammaNNO5,t,gammaN13NO5)
% axis([0 10 10^(-5) 0.1]);
xlabel('Time (s)');ylabel('gamma');
legend('gamma(N2O5)','gamma(N13NO5)','Location','NorthEastOutside'); % legend

%plot for rates labelled
figure('Position',[scrsz(3)/2 1 scrsz(3)/2 scrsz(4)/2])
semilogy(t,RN13O2pNO3m,t,RN13O2pH2O,t,RN13O3mNO2p,t,RN13NO5diss)
xlabel('Time (s)');ylabel('M/s'); % plot axis label
legend('N*O2+ + NO3-','N*O2+ + H2O ','N*O3- + NO2+','N*NO5-->N*O2+ + NO3-','Location','NorthEastOutside'); % legend

%plot rates non-labelled
figure('Position',[scrsz(3)/2 1 scrsz(3)/2 scrsz(4)/2])
semilogy(t,RNO2pNO3m,t,RNO2pH2O,t,RNO3mNO2p,t,RNNO5diss)
xlabel('Time (s)');ylabel('M/s'); % plot axis label
legend('NO2+ + NO3-','NO2+ + H2O ','NO3- + NO2+','N2O5-->NO2+ + NO3-','Location','NorthEastOutside'); % legend

% output to spreadsheet
xlswrite('Mentel_NaNO3_70RH.xlsx',[t,C,CnormN13NO5,CnormN13O3,CnormNNO5,CnormNO3,...
    fracN13NO5,ratioN13O3,gammaN13NO5,gammaNNO5,...
    RN13O2pNO3m,RN13O2pH2O,RN13O3mNO2p,RN13NO5diss...
    RNO2pNO3m,RNO2pH2O,RNO3mNO2p,RNNO5diss]);